@@ -45,6 +45,7 @@ enum  {
 static ValaTypeSymbol* vala_interface_register_function_real_get_type_declaration (ValaTypeRegisterFunction* base);
 static char* vala_interface_register_function_real_get_type_struct_name (ValaTypeRegisterFunction* base);
 static char* vala_interface_register_function_real_get_base_init_func_name (ValaTypeRegisterFunction* base);
+static char* vala_interface_register_function_real_get_base_finalize_func_name (ValaTypeRegisterFunction* base);
 static char* vala_interface_register_function_real_get_class_init_func_name (ValaTypeRegisterFunction* base);
 static char* vala_interface_register_function_real_get_instance_struct_size (ValaTypeRegisterFunction* base);
 static char* vala_interface_register_function_real_get_instance_init_func_name (ValaTypeRegisterFunction* base);
@@ -99,6 +100,13 @@ static char* vala_interface_register_function_real_get_base_init_func_name (Vala
 }
 
 
+static char* vala_interface_register_function_real_get_base_finalize_func_name (ValaTypeRegisterFunction* base) {
+	ValaInterfaceRegisterFunction * self;
+	self = (ValaInterfaceRegisterFunction*) base;
+	return g_strdup ("NULL");
+}
+
+
 static char* vala_interface_register_function_real_get_class_init_func_name (ValaTypeRegisterFunction* base) {
 	ValaInterfaceRegisterFunction * self;
 	self = (ValaInterfaceRegisterFunction*) base;
@@ -143,13 +151,13 @@ static ValaCCodeFragment* vala_interface_register_function_real_get_type_interfa
 	{
 		GeeList* _tmp0;
 		GeeIterator* _tmp1;
-		GeeIterator* prereq_ref_it;
+		GeeIterator* _prereq_ref_it;
 		/* register all prerequisites */
 		_tmp0 = NULL;
 		_tmp1 = NULL;
-		prereq_ref_it = (_tmp1 = gee_iterable_iterator ((GeeIterable*) (_tmp0 = vala_interface_get_prerequisites (self->priv->_interface_reference))), (_tmp0 == NULL) ? NULL : (_tmp0 = (gee_collection_object_unref (_tmp0), NULL)), _tmp1);
+		_prereq_ref_it = (_tmp1 = gee_iterable_iterator ((GeeIterable*) (_tmp0 = vala_interface_get_prerequisites (self->priv->_interface_reference))), (_tmp0 == NULL) ? NULL : (_tmp0 = (gee_collection_object_unref (_tmp0), NULL)), _tmp1);
 		/* register all prerequisites */
-		while (gee_iterator_next (prereq_ref_it)) {
+		while (gee_iterator_next (_prereq_ref_it)) {
 			ValaDataType* prereq_ref;
 			ValaTypeSymbol* _tmp2;
 			ValaTypeSymbol* prereq;
@@ -163,7 +171,7 @@ static ValaCCodeFragment* vala_interface_register_function_real_get_type_interfa
 			char* _tmp8;
 			ValaCCodeExpressionStatement* _tmp10;
 			/* register all prerequisites */
-			prereq_ref = (ValaDataType*) gee_iterator_get (prereq_ref_it);
+			prereq_ref = (ValaDataType*) gee_iterator_get (_prereq_ref_it);
 			_tmp2 = NULL;
 			prereq = (_tmp2 = vala_data_type_get_data_type (prereq_ref), (_tmp2 == NULL) ? NULL : vala_code_node_ref (_tmp2));
 			_tmp3 = NULL;
@@ -188,7 +196,7 @@ static ValaCCodeFragment* vala_interface_register_function_real_get_type_interfa
 			(prereq == NULL) ? NULL : (prereq = (vala_code_node_unref (prereq), NULL));
 			(func == NULL) ? NULL : (func = (vala_ccode_node_unref (func), NULL));
 		}
-		(prereq_ref_it == NULL) ? NULL : (prereq_ref_it = (gee_collection_object_unref (prereq_ref_it), NULL));
+		(_prereq_ref_it == NULL) ? NULL : (_prereq_ref_it = (gee_collection_object_unref (_prereq_ref_it), NULL));
 	}
 	return frag;
 }
@@ -213,6 +221,7 @@ static void vala_interface_register_function_class_init (ValaInterfaceRegisterFu
 	VALA_TYPEREGISTER_FUNCTION_CLASS (klass)->get_type_declaration = vala_interface_register_function_real_get_type_declaration;
 	VALA_TYPEREGISTER_FUNCTION_CLASS (klass)->get_type_struct_name = vala_interface_register_function_real_get_type_struct_name;
 	VALA_TYPEREGISTER_FUNCTION_CLASS (klass)->get_base_init_func_name = vala_interface_register_function_real_get_base_init_func_name;
+	VALA_TYPEREGISTER_FUNCTION_CLASS (klass)->get_base_finalize_func_name = vala_interface_register_function_real_get_base_finalize_func_name;
 	VALA_TYPEREGISTER_FUNCTION_CLASS (klass)->get_class_init_func_name = vala_interface_register_function_real_get_class_init_func_name;
 	VALA_TYPEREGISTER_FUNCTION_CLASS (klass)->get_instance_struct_size = vala_interface_register_function_real_get_instance_struct_size;
 	VALA_TYPEREGISTER_FUNCTION_CLASS (klass)->get_instance_init_func_name = vala_interface_register_function_real_get_instance_init_func_name;
