@@ -109,15 +109,15 @@ static void vala_array_creation_expression_real_accept_children (ValaCodeNode* b
 		vala_code_node_accept ((ValaCodeNode*) vala_array_creation_expression_get_element_type (self), visitor);
 	}
 	{
-		GeeIterator* e_it;
-		e_it = gee_iterable_iterator ((GeeIterable*) self->priv->sizes);
-		while (gee_iterator_next (e_it)) {
+		GeeIterator* _e_it;
+		_e_it = gee_iterable_iterator ((GeeIterable*) self->priv->sizes);
+		while (gee_iterator_next (_e_it)) {
 			ValaExpression* e;
-			e = (ValaExpression*) gee_iterator_get (e_it);
+			e = (ValaExpression*) gee_iterator_get (_e_it);
 			vala_code_node_accept ((ValaCodeNode*) e, visitor);
 			(e == NULL) ? NULL : (e = (vala_code_node_unref (e), NULL));
 		}
-		(e_it == NULL) ? NULL : (e_it = (gee_collection_object_unref (e_it), NULL));
+		(_e_it == NULL) ? NULL : (_e_it = (gee_collection_object_unref (_e_it), NULL));
 	}
 	if (self->priv->_initializer_list != NULL) {
 		vala_code_node_accept ((ValaCodeNode*) self->priv->_initializer_list, visitor);
@@ -171,13 +171,13 @@ static gint vala_array_creation_expression_create_sizes_from_initializer_list (V
 	{
 		GeeList* _tmp2;
 		GeeIterator* _tmp3;
-		GeeIterator* e_it;
+		GeeIterator* _e_it;
 		_tmp2 = NULL;
 		_tmp3 = NULL;
-		e_it = (_tmp3 = gee_iterable_iterator ((GeeIterable*) (_tmp2 = vala_initializer_list_get_initializers (il))), (_tmp2 == NULL) ? NULL : (_tmp2 = (gee_collection_object_unref (_tmp2), NULL)), _tmp3);
-		while (gee_iterator_next (e_it)) {
+		_e_it = (_tmp3 = gee_iterable_iterator ((GeeIterable*) (_tmp2 = vala_initializer_list_get_initializers (il))), (_tmp2 == NULL) ? NULL : (_tmp2 = (gee_collection_object_unref (_tmp2), NULL)), _tmp3);
+		while (gee_iterator_next (_e_it)) {
 			ValaExpression* e;
-			e = (ValaExpression*) gee_iterator_get (e_it);
+			e = (ValaExpression*) gee_iterator_get (_e_it);
 			if (VALA_IS_INITIALIZER_LIST (e)) {
 				gint size;
 				gboolean _tmp6;
@@ -186,12 +186,12 @@ static gint vala_array_creation_expression_create_sizes_from_initializer_list (V
 					vala_code_node_set_error ((ValaCodeNode*) il, TRUE);
 					vala_code_node_set_error ((ValaCodeNode*) e, TRUE);
 					vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) e), "Expected array element, got array initializer list");
-					return (_tmp4 = -1, (e == NULL) ? NULL : (e = (vala_code_node_unref (e), NULL)), (e_it == NULL) ? NULL : (e_it = (gee_collection_object_unref (e_it), NULL)), (init == NULL) ? NULL : (init = (vala_code_node_unref (init), NULL)), _tmp4);
+					return (_tmp4 = -1, (e == NULL) ? NULL : (e = (vala_code_node_unref (e), NULL)), (_e_it == NULL) ? NULL : (_e_it = (gee_collection_object_unref (_e_it), NULL)), (init == NULL) ? NULL : (init = (vala_code_node_unref (init), NULL)), _tmp4);
 				}
 				size = vala_array_creation_expression_create_sizes_from_initializer_list (self, analyzer, VALA_INITIALIZER_LIST (e), rank - 1, sl);
 				if (size == (-1)) {
 					gint _tmp5;
-					return (_tmp5 = -1, (e == NULL) ? NULL : (e = (vala_code_node_unref (e), NULL)), (e_it == NULL) ? NULL : (e_it = (gee_collection_object_unref (e_it), NULL)), (init == NULL) ? NULL : (init = (vala_code_node_unref (init), NULL)), _tmp5);
+					return (_tmp5 = -1, (e == NULL) ? NULL : (e = (vala_code_node_unref (e), NULL)), (_e_it == NULL) ? NULL : (_e_it = (gee_collection_object_unref (_e_it), NULL)), (init == NULL) ? NULL : (init = (vala_code_node_unref (init), NULL)), _tmp5);
 				}
 				_tmp6 = FALSE;
 				if (subsize >= 0) {
@@ -206,7 +206,7 @@ static gint vala_array_creation_expression_create_sizes_from_initializer_list (V
 					_tmp7 = NULL;
 					vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) il), _tmp7 = g_strdup_printf ("Expected initializer list of size %d, got size %d", subsize, size));
 					_tmp7 = (g_free (_tmp7), NULL);
-					return (_tmp8 = -1, (e == NULL) ? NULL : (e = (vala_code_node_unref (e), NULL)), (e_it == NULL) ? NULL : (e_it = (gee_collection_object_unref (e_it), NULL)), (init == NULL) ? NULL : (init = (vala_code_node_unref (init), NULL)), _tmp8);
+					return (_tmp8 = -1, (e == NULL) ? NULL : (e = (vala_code_node_unref (e), NULL)), (_e_it == NULL) ? NULL : (_e_it = (gee_collection_object_unref (_e_it), NULL)), (init == NULL) ? NULL : (init = (vala_code_node_unref (init), NULL)), _tmp8);
 				} else {
 					subsize = size;
 				}
@@ -216,12 +216,12 @@ static gint vala_array_creation_expression_create_sizes_from_initializer_list (V
 					vala_code_node_set_error ((ValaCodeNode*) il, TRUE);
 					vala_code_node_set_error ((ValaCodeNode*) e, TRUE);
 					vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) e), "Expected array initializer list, got array element");
-					return (_tmp9 = -1, (e == NULL) ? NULL : (e = (vala_code_node_unref (e), NULL)), (e_it == NULL) ? NULL : (e_it = (gee_collection_object_unref (e_it), NULL)), (init == NULL) ? NULL : (init = (vala_code_node_unref (init), NULL)), _tmp9);
+					return (_tmp9 = -1, (e == NULL) ? NULL : (e = (vala_code_node_unref (e), NULL)), (_e_it == NULL) ? NULL : (_e_it = (gee_collection_object_unref (_e_it), NULL)), (init == NULL) ? NULL : (init = (vala_code_node_unref (init), NULL)), _tmp9);
 				}
 			}
 			(e == NULL) ? NULL : (e = (vala_code_node_unref (e), NULL));
 		}
-		(e_it == NULL) ? NULL : (e_it = (gee_collection_object_unref (e_it), NULL));
+		(_e_it == NULL) ? NULL : (_e_it = (gee_collection_object_unref (_e_it), NULL));
 	}
 	return (_tmp10 = vala_initializer_list_get_size (il), (init == NULL) ? NULL : (init = (vala_code_node_unref (init), NULL)), _tmp10);
 }
@@ -229,7 +229,7 @@ static gint vala_array_creation_expression_create_sizes_from_initializer_list (V
 
 static gboolean vala_array_creation_expression_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer) {
 	ValaArrayCreationExpression * self;
-	GeeList* size;
+	GeeList* sizes;
 	ValaInitializerList* _tmp1;
 	ValaInitializerList* initlist;
 	GeeArrayList* calc_sizes;
@@ -242,22 +242,22 @@ static gboolean vala_array_creation_expression_real_check (ValaCodeNode* base, V
 		return !vala_code_node_get_error ((ValaCodeNode*) self);
 	}
 	vala_code_node_set_checked ((ValaCodeNode*) self, TRUE);
-	size = vala_array_creation_expression_get_sizes (self);
+	sizes = vala_array_creation_expression_get_sizes (self);
 	_tmp1 = NULL;
 	initlist = (_tmp1 = self->priv->_initializer_list, (_tmp1 == NULL) ? NULL : vala_code_node_ref (_tmp1));
 	if (vala_array_creation_expression_get_element_type (self) != NULL) {
 		vala_code_node_check ((ValaCodeNode*) vala_array_creation_expression_get_element_type (self), analyzer);
 	}
 	{
-		GeeIterator* e_it;
-		e_it = gee_iterable_iterator ((GeeIterable*) size);
-		while (gee_iterator_next (e_it)) {
+		GeeIterator* _e_it;
+		_e_it = gee_iterable_iterator ((GeeIterable*) sizes);
+		while (gee_iterator_next (_e_it)) {
 			ValaExpression* e;
-			e = (ValaExpression*) gee_iterator_get (e_it);
+			e = (ValaExpression*) gee_iterator_get (_e_it);
 			vala_code_node_check ((ValaCodeNode*) e, analyzer);
 			(e == NULL) ? NULL : (e = (vala_code_node_unref (e), NULL));
 		}
-		(e_it == NULL) ? NULL : (e_it = (gee_collection_object_unref (e_it), NULL));
+		(_e_it == NULL) ? NULL : (_e_it = (gee_collection_object_unref (_e_it), NULL));
 	}
 	calc_sizes = gee_array_list_new (VALA_TYPE_LITERAL, (GBoxedCopyFunc) vala_code_node_ref, vala_code_node_unref, g_direct_equal);
 	if (initlist != NULL) {
@@ -272,21 +272,21 @@ static gboolean vala_array_creation_expression_real_check (ValaCodeNode* base, V
 			vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
 		}
 	}
-	if (gee_collection_get_size ((GeeCollection*) size) > 0) {
+	if (gee_collection_get_size ((GeeCollection*) sizes) > 0) {
 		/* check for errors in the size list */
 		{
-			GeeIterator* e_it;
+			GeeIterator* _e_it;
 			/* check for errors in the size list */
-			e_it = gee_iterable_iterator ((GeeIterable*) size);
+			_e_it = gee_iterable_iterator ((GeeIterable*) sizes);
 			/* check for errors in the size list */
-			while (gee_iterator_next (e_it)) {
+			while (gee_iterator_next (_e_it)) {
 				ValaExpression* e;
 				/* check for errors in the size list */
-				e = (ValaExpression*) gee_iterator_get (e_it);
+				e = (ValaExpression*) gee_iterator_get (_e_it);
 				if (vala_expression_get_value_type (e) == NULL) {
 					gboolean _tmp3;
 					/* return on previous error */
-					return (_tmp3 = FALSE, (e == NULL) ? NULL : (e = (vala_code_node_unref (e), NULL)), (e_it == NULL) ? NULL : (e_it = (gee_collection_object_unref (e_it), NULL)), (size == NULL) ? NULL : (size = (gee_collection_object_unref (size), NULL)), (initlist == NULL) ? NULL : (initlist = (vala_code_node_unref (initlist), NULL)), (calc_sizes == NULL) ? NULL : (calc_sizes = (gee_collection_object_unref (calc_sizes), NULL)), _tmp3);
+					return (_tmp3 = FALSE, (e == NULL) ? NULL : (e = (vala_code_node_unref (e), NULL)), (_e_it == NULL) ? NULL : (_e_it = (gee_collection_object_unref (_e_it), NULL)), (sizes == NULL) ? NULL : (sizes = (gee_collection_object_unref (sizes), NULL)), (initlist == NULL) ? NULL : (initlist = (vala_code_node_unref (initlist), NULL)), (calc_sizes == NULL) ? NULL : (calc_sizes = (gee_collection_object_unref (calc_sizes), NULL)), _tmp3);
 				} else {
 					if (!vala_data_type_compatible (vala_expression_get_value_type (e), analyzer->uint64_type)) {
 						vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
@@ -295,7 +295,7 @@ static gboolean vala_array_creation_expression_real_check (ValaCodeNode* base, V
 				}
 				(e == NULL) ? NULL : (e = (vala_code_node_unref (e), NULL));
 			}
-			(e_it == NULL) ? NULL : (e_it = (gee_collection_object_unref (e_it), NULL));
+			(_e_it == NULL) ? NULL : (_e_it = (gee_collection_object_unref (_e_it), NULL));
 		}
 	} else {
 		if (initlist == NULL) {
@@ -304,21 +304,21 @@ static gboolean vala_array_creation_expression_real_check (ValaCodeNode* base, V
 			vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), "internal error: initializer list expected");
 		} else {
 			{
-				GeeIterator* size_it;
-				size_it = gee_iterable_iterator ((GeeIterable*) calc_sizes);
-				while (gee_iterator_next (size_it)) {
+				GeeIterator* _size_it;
+				_size_it = gee_iterable_iterator ((GeeIterable*) calc_sizes);
+				while (gee_iterator_next (_size_it)) {
 					ValaExpression* size;
-					size = (ValaExpression*) ((ValaLiteral*) gee_iterator_get (size_it));
+					size = (ValaExpression*) ((ValaLiteral*) gee_iterator_get (_size_it));
 					vala_array_creation_expression_append_size (self, size);
 					(size == NULL) ? NULL : (size = (vala_code_node_unref (size), NULL));
 				}
-				(size_it == NULL) ? NULL : (size_it = (gee_collection_object_unref (size_it), NULL));
+				(_size_it == NULL) ? NULL : (_size_it = (gee_collection_object_unref (_size_it), NULL));
 			}
 		}
 	}
 	if (vala_code_node_get_error ((ValaCodeNode*) self)) {
 		gboolean _tmp4;
-		return (_tmp4 = FALSE, (size == NULL) ? NULL : (size = (gee_collection_object_unref (size), NULL)), (initlist == NULL) ? NULL : (initlist = (vala_code_node_unref (initlist), NULL)), (calc_sizes == NULL) ? NULL : (calc_sizes = (gee_collection_object_unref (calc_sizes), NULL)), _tmp4);
+		return (_tmp4 = FALSE, (sizes == NULL) ? NULL : (sizes = (gee_collection_object_unref (sizes), NULL)), (initlist == NULL) ? NULL : (initlist = (vala_code_node_unref (initlist), NULL)), (calc_sizes == NULL) ? NULL : (calc_sizes = (gee_collection_object_unref (calc_sizes), NULL)), _tmp4);
 	}
 	_tmp5 = FALSE;
 	if (self->priv->_initializer_list != NULL) {
@@ -329,21 +329,21 @@ static gboolean vala_array_creation_expression_real_check (ValaCodeNode* base, V
 	/* check for wrong elements inside the initializer */
 	if (_tmp5) {
 		gboolean _tmp6;
-		return (_tmp6 = FALSE, (size == NULL) ? NULL : (size = (gee_collection_object_unref (size), NULL)), (initlist == NULL) ? NULL : (initlist = (vala_code_node_unref (initlist), NULL)), (calc_sizes == NULL) ? NULL : (calc_sizes = (gee_collection_object_unref (calc_sizes), NULL)), _tmp6);
+		return (_tmp6 = FALSE, (sizes == NULL) ? NULL : (sizes = (gee_collection_object_unref (sizes), NULL)), (initlist == NULL) ? NULL : (initlist = (vala_code_node_unref (initlist), NULL)), (calc_sizes == NULL) ? NULL : (calc_sizes = (gee_collection_object_unref (calc_sizes), NULL)), _tmp6);
 	}
 	/* try to construct the type of the array */
 	if (vala_array_creation_expression_get_element_type (self) == NULL) {
 		gboolean _tmp7;
 		vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
 		vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), "Cannot determine the element type of the created array");
-		return (_tmp7 = FALSE, (size == NULL) ? NULL : (size = (gee_collection_object_unref (size), NULL)), (initlist == NULL) ? NULL : (initlist = (vala_code_node_unref (initlist), NULL)), (calc_sizes == NULL) ? NULL : (calc_sizes = (gee_collection_object_unref (calc_sizes), NULL)), _tmp7);
+		return (_tmp7 = FALSE, (sizes == NULL) ? NULL : (sizes = (gee_collection_object_unref (sizes), NULL)), (initlist == NULL) ? NULL : (initlist = (vala_code_node_unref (initlist), NULL)), (calc_sizes == NULL) ? NULL : (calc_sizes = (gee_collection_object_unref (calc_sizes), NULL)), _tmp7);
 	}
 	vala_data_type_set_value_owned (vala_array_creation_expression_get_element_type (self), TRUE);
 	_tmp8 = NULL;
 	vala_expression_set_value_type ((ValaExpression*) self, (ValaDataType*) (_tmp8 = vala_array_type_new (vala_array_creation_expression_get_element_type (self), self->priv->_rank, vala_code_node_get_source_reference ((ValaCodeNode*) self))));
 	(_tmp8 == NULL) ? NULL : (_tmp8 = (vala_code_node_unref (_tmp8), NULL));
 	vala_data_type_set_value_owned (vala_expression_get_value_type ((ValaExpression*) self), TRUE);
-	return (_tmp9 = !vala_code_node_get_error ((ValaCodeNode*) self), (size == NULL) ? NULL : (size = (gee_collection_object_unref (size), NULL)), (initlist == NULL) ? NULL : (initlist = (vala_code_node_unref (initlist), NULL)), (calc_sizes == NULL) ? NULL : (calc_sizes = (gee_collection_object_unref (calc_sizes), NULL)), _tmp9);
+	return (_tmp9 = !vala_code_node_get_error ((ValaCodeNode*) self), (sizes == NULL) ? NULL : (sizes = (gee_collection_object_unref (sizes), NULL)), (initlist == NULL) ? NULL : (initlist = (vala_code_node_unref (initlist), NULL)), (calc_sizes == NULL) ? NULL : (calc_sizes = (gee_collection_object_unref (calc_sizes), NULL)), _tmp9);
 }
 
 
