@@ -97,6 +97,7 @@ void vala_class_set_is_immutable (ValaClass* self, gboolean value);
 const char* vala_class_get_type_check_function (ValaClass* self);
 void vala_class_set_type_check_function (ValaClass* self, const char* value);
 gboolean vala_class_get_has_private_fields (ValaClass* self);
+gboolean vala_class_get_has_class_private_fields (ValaClass* self);
 ValaMethod* vala_class_get_default_construction_method (ValaClass* self);
 void vala_class_set_default_construction_method (ValaClass* self, ValaMethod* value);
 ValaConstructor* vala_class_get_constructor (ValaClass* self);
@@ -107,6 +108,8 @@ ValaConstructor* vala_class_get_static_constructor (ValaClass* self);
 void vala_class_set_static_constructor (ValaClass* self, ValaConstructor* value);
 ValaDestructor* vala_class_get_destructor (ValaClass* self);
 void vala_class_set_destructor (ValaClass* self, ValaDestructor* value);
+ValaDestructor* vala_class_get_class_destructor (ValaClass* self);
+void vala_class_set_class_destructor (ValaClass* self, ValaDestructor* value);
 gboolean vala_class_get_is_error_base (ValaClass* self);
 GType vala_class_get_type (void);
 
