@@ -207,15 +207,15 @@ void vala_code_context_accept (ValaCodeContext* self, ValaCodeVisitor* visitor)
 	g_return_if_fail (visitor != NULL);
 	vala_code_node_accept ((ValaCodeNode*) vala_code_context_get_root (self), visitor);
 	{
-		GeeIterator* file_it;
-		file_it = gee_iterable_iterator ((GeeIterable*) self->priv->source_files);
-		while (gee_iterator_next (file_it)) {
+		GeeIterator* _file_it;
+		_file_it = gee_iterable_iterator ((GeeIterable*) self->priv->source_files);
+		while (gee_iterator_next (_file_it)) {
 			ValaSourceFile* file;
-			file = (ValaSourceFile*) gee_iterator_get (file_it);
+			file = (ValaSourceFile*) gee_iterator_get (_file_it);
 			vala_source_file_accept (file, visitor);
 			(file == NULL) ? NULL : (file = (vala_source_file_unref (file), NULL));
 		}
-		(file_it == NULL) ? NULL : (file_it = (gee_collection_object_unref (file_it), NULL));
+		(_file_it == NULL) ? NULL : (_file_it = (gee_collection_object_unref (_file_it), NULL));
 	}
 }
 
@@ -227,14 +227,14 @@ void vala_code_context_find_header_cycles (ValaCodeContext* self) {
 	g_return_if_fail (self != NULL);
 	/* find cycles in dependencies between source files */
 	{
-		GeeIterator* file_it;
+		GeeIterator* _file_it;
 		/* find cycles in dependencies between source files */
-		file_it = gee_iterable_iterator ((GeeIterable*) self->priv->source_files);
+		_file_it = gee_iterable_iterator ((GeeIterable*) self->priv->source_files);
 		/* find cycles in dependencies between source files */
-		while (gee_iterator_next (file_it)) {
+		while (gee_iterator_next (_file_it)) {
 			ValaSourceFile* file;
 			/* find cycles in dependencies between source files */
-			file = (ValaSourceFile*) gee_iterator_get (file_it);
+			file = (ValaSourceFile*) gee_iterator_get (_file_it);
 			/* we're only interested in internal source files */
 			if (vala_source_file_get_external_package (file)) {
 				(file == NULL) ? NULL : (file = (vala_source_file_unref (file), NULL));
@@ -248,50 +248,50 @@ void vala_code_context_find_header_cycles (ValaCodeContext* self) {
 			}
 			(file == NULL) ? NULL : (file = (vala_source_file_unref (file), NULL));
 		}
-		(file_it == NULL) ? NULL : (file_it = (gee_collection_object_unref (file_it), NULL));
+		(_file_it == NULL) ? NULL : (_file_it = (gee_collection_object_unref (_file_it), NULL));
 	}
 	/* find one head for each cycle, it must not have any
 	 * hard dependencies on other files in the cycle
 	 */
 	{
-		GeeIterator* cycle_it;
+		GeeIterator* _cycle_it;
 		/* find one head for each cycle, it must not have any
 		 * hard dependencies on other files in the cycle
 		 */
-		cycle_it = gee_iterable_iterator ((GeeIterable*) self->priv->cycles);
+		_cycle_it = gee_iterable_iterator ((GeeIterable*) self->priv->cycles);
 		/* find one head for each cycle, it must not have any
 		 * hard dependencies on other files in the cycle
 		 */
-		while (gee_iterator_next (cycle_it)) {
+		while (gee_iterator_next (_cycle_it)) {
 			ValaSourceFileCycle* cycle;
 			/* find one head for each cycle, it must not have any
 			 * hard dependencies on other files in the cycle
 			 */
-			cycle = (ValaSourceFileCycle*) gee_iterator_get (cycle_it);
+			cycle = (ValaSourceFileCycle*) gee_iterator_get (_cycle_it);
 			cycle->head = vala_code_context_find_cycle_head (self, (ValaSourceFile*) gee_list_get (cycle->files, 0));
 			vala_source_file_set_is_cycle_head (cycle->head, TRUE);
 			(cycle == NULL) ? NULL : (cycle = (vala_source_file_cycle_unref (cycle), NULL));
 		}
-		(cycle_it == NULL) ? NULL : (cycle_it = (gee_collection_object_unref (cycle_it), NULL));
+		(_cycle_it == NULL) ? NULL : (_cycle_it = (gee_collection_object_unref (_cycle_it), NULL));
 	}
 	/* connect the source files in a non-cyclic way
 	 * cycle members connect to the head of their cycle
 	 */
 	{
-		GeeIterator* file2_it;
+		GeeIterator* _file2_it;
 		/* connect the source files in a non-cyclic way
 		 * cycle members connect to the head of their cycle
 		 */
-		file2_it = gee_iterable_iterator ((GeeIterable*) self->priv->source_files);
+		_file2_it = gee_iterable_iterator ((GeeIterable*) self->priv->source_files);
 		/* connect the source files in a non-cyclic way
 		 * cycle members connect to the head of their cycle
 		 */
-		while (gee_iterator_next (file2_it)) {
+		while (gee_iterator_next (_file2_it)) {
 			ValaSourceFile* file2;
 			/* connect the source files in a non-cyclic way
 			 * cycle members connect to the head of their cycle
 			 */
-			file2 = (ValaSourceFile*) gee_iterator_get (file2_it);
+			file2 = (ValaSourceFile*) gee_iterator_get (_file2_it);
 			/* we're only interested in internal source files */
 			if (vala_source_file_get_external_package (file2)) {
 				(file2 == NULL) ? NULL : (file2 = (vala_source_file_unref (file2), NULL));
@@ -300,16 +300,16 @@ void vala_code_context_find_header_cycles (ValaCodeContext* self) {
 			{
 				GeeList* _tmp1;
 				GeeIterator* _tmp2;
-				GeeIterator* dep_it;
+				GeeIterator* _dep_it;
 				_tmp1 = NULL;
 				_tmp2 = NULL;
-				dep_it = (_tmp2 = gee_iterable_iterator ((GeeIterable*) (_tmp1 = vala_source_file_get_header_internal_dependencies (file2))), (_tmp1 == NULL) ? NULL : (_tmp1 = (gee_collection_object_unref (_tmp1), NULL)), _tmp2);
-				while (gee_iterator_next (dep_it)) {
+				_dep_it = (_tmp2 = gee_iterable_iterator ((GeeIterable*) (_tmp1 = vala_source_file_get_header_internal_dependencies (file2))), (_tmp1 == NULL) ? NULL : (_tmp1 = (gee_collection_object_unref (_tmp1), NULL)), _tmp2);
+				while (gee_iterator_next (_dep_it)) {
 					ValaSourceFile* _tmp3;
 					ValaSourceFile* dep;
 					gboolean _tmp4;
 					_tmp3 = NULL;
-					dep = (_tmp3 = (ValaSourceFile*) gee_iterator_get (dep_it), (_tmp3 == NULL) ? NULL : vala_source_file_ref (_tmp3));
+					dep = (_tmp3 = (ValaSourceFile*) gee_iterator_get (_dep_it), (_tmp3 == NULL) ? NULL : vala_source_file_ref (_tmp3));
 					_tmp4 = FALSE;
 					if (vala_source_file_get_cycle (file2) != NULL) {
 						_tmp4 = vala_source_file_get_cycle (dep) == vala_source_file_get_cycle (file2);
@@ -334,11 +334,11 @@ void vala_code_context_find_header_cycles (ValaCodeContext* self) {
 					}
 					(dep == NULL) ? NULL : (dep = (vala_source_file_unref (dep), NULL));
 				}
-				(dep_it == NULL) ? NULL : (dep_it = (gee_collection_object_unref (dep_it), NULL));
+				(_dep_it == NULL) ? NULL : (_dep_it = (gee_collection_object_unref (_dep_it), NULL));
 			}
 			(file2 == NULL) ? NULL : (file2 = (vala_source_file_unref (file2), NULL));
 		}
-		(file2_it == NULL) ? NULL : (file2_it = (gee_collection_object_unref (file2_it), NULL));
+		(_file2_it == NULL) ? NULL : (_file2_it = (gee_collection_object_unref (_file2_it), NULL));
 	}
 }
 
@@ -349,40 +349,40 @@ static ValaSourceFile* vala_code_context_find_cycle_head (ValaCodeContext* self,
 	{
 		GeeList* _tmp0;
 		GeeIterator* _tmp1;
-		GeeIterator* dep_it;
+		GeeIterator* _dep_it;
 		_tmp0 = NULL;
 		_tmp1 = NULL;
-		dep_it = (_tmp1 = gee_iterable_iterator ((GeeIterable*) (_tmp0 = vala_source_file_get_header_internal_full_dependencies (file))), (_tmp0 == NULL) ? NULL : (_tmp0 = (gee_collection_object_unref (_tmp0), NULL)), _tmp1);
-		while (gee_iterator_next (dep_it)) {
+		_dep_it = (_tmp1 = gee_iterable_iterator ((GeeIterable*) (_tmp0 = vala_source_file_get_header_internal_full_dependencies (file))), (_tmp0 == NULL) ? NULL : (_tmp0 = (gee_collection_object_unref (_tmp0), NULL)), _tmp1);
+		while (gee_iterator_next (_dep_it)) {
 			ValaSourceFile* _tmp2;
 			ValaSourceFile* dep;
 			_tmp2 = NULL;
-			dep = (_tmp2 = (ValaSourceFile*) gee_iterator_get (dep_it), (_tmp2 == NULL) ? NULL : vala_source_file_ref (_tmp2));
+			dep = (_tmp2 = (ValaSourceFile*) gee_iterator_get (_dep_it), (_tmp2 == NULL) ? NULL : vala_source_file_ref (_tmp2));
 			if (dep == file) {
 				/* ignore file-internal dependencies */
 				(dep == NULL) ? NULL : (dep = (vala_source_file_unref (dep), NULL));
 				continue;
 			}
 			{
-				GeeIterator* cycle_file_it;
-				cycle_file_it = gee_iterable_iterator ((GeeIterable*) vala_source_file_get_cycle (file)->files);
-				while (gee_iterator_next (cycle_file_it)) {
+				GeeIterator* _cycle_file_it;
+				_cycle_file_it = gee_iterable_iterator ((GeeIterable*) vala_source_file_get_cycle (file)->files);
+				while (gee_iterator_next (_cycle_file_it)) {
 					ValaSourceFile* _tmp3;
 					ValaSourceFile* cycle_file;
 					_tmp3 = NULL;
-					cycle_file = (_tmp3 = (ValaSourceFile*) gee_iterator_get (cycle_file_it), (_tmp3 == NULL) ? NULL : vala_source_file_ref (_tmp3));
+					cycle_file = (_tmp3 = (ValaSourceFile*) gee_iterator_get (_cycle_file_it), (_tmp3 == NULL) ? NULL : vala_source_file_ref (_tmp3));
 					if (dep == cycle_file) {
 						ValaSourceFile* _tmp4;
 						_tmp4 = NULL;
-						return (_tmp4 = vala_code_context_find_cycle_head (self, dep), (cycle_file == NULL) ? NULL : (cycle_file = (vala_source_file_unref (cycle_file), NULL)), (cycle_file_it == NULL) ? NULL : (cycle_file_it = (gee_collection_object_unref (cycle_file_it), NULL)), (dep == NULL) ? NULL : (dep = (vala_source_file_unref (dep), NULL)), (dep_it == NULL) ? NULL : (dep_it = (gee_collection_object_unref (dep_it), NULL)), _tmp4);
+						return (_tmp4 = vala_code_context_find_cycle_head (self, dep), (cycle_file == NULL) ? NULL : (cycle_file = (vala_source_file_unref (cycle_file), NULL)), (_cycle_file_it == NULL) ? NULL : (_cycle_file_it = (gee_collection_object_unref (_cycle_file_it), NULL)), (dep == NULL) ? NULL : (dep = (vala_source_file_unref (dep), NULL)), (_dep_it == NULL) ? NULL : (_dep_it = (gee_collection_object_unref (_dep_it), NULL)), _tmp4);
 					}
 					(cycle_file == NULL) ? NULL : (cycle_file = (vala_source_file_unref (cycle_file), NULL));
 				}
-				(cycle_file_it == NULL) ? NULL : (cycle_file_it = (gee_collection_object_unref (cycle_file_it), NULL));
+				(_cycle_file_it == NULL) ? NULL : (_cycle_file_it = (gee_collection_object_unref (_cycle_file_it), NULL));
 			}
 			(dep == NULL) ? NULL : (dep = (vala_source_file_unref (dep), NULL));
 		}
-		(dep_it == NULL) ? NULL : (dep_it = (gee_collection_object_unref (dep_it), NULL));
+		(_dep_it == NULL) ? NULL : (_dep_it = (gee_collection_object_unref (_dep_it), NULL));
 	}
 	/* no hard dependencies on members of the same cycle found
 	 * source file suitable as cycle head
@@ -398,15 +398,15 @@ static void vala_code_context_visit (ValaCodeContext* self, ValaSourceFile* file
 	g_return_if_fail (chain != NULL);
 	l = (GeeList*) gee_array_list_new (VALA_TYPE_SOURCE_FILE, (GBoxedCopyFunc) vala_source_file_ref, vala_source_file_unref, g_direct_equal);
 	{
-		GeeIterator* chain_file_it;
-		chain_file_it = gee_iterable_iterator ((GeeIterable*) chain);
-		while (gee_iterator_next (chain_file_it)) {
+		GeeIterator* _chain_file_it;
+		_chain_file_it = gee_iterable_iterator ((GeeIterable*) chain);
+		while (gee_iterator_next (_chain_file_it)) {
 			ValaSourceFile* chain_file;
-			chain_file = (ValaSourceFile*) gee_iterator_get (chain_file_it);
+			chain_file = (ValaSourceFile*) gee_iterator_get (_chain_file_it);
 			gee_collection_add ((GeeCollection*) l, chain_file);
 			(chain_file == NULL) ? NULL : (chain_file = (vala_source_file_unref (chain_file), NULL));
 		}
-		(chain_file_it == NULL) ? NULL : (chain_file_it = (gee_collection_object_unref (chain_file_it), NULL));
+		(_chain_file_it == NULL) ? NULL : (_chain_file_it = (gee_collection_object_unref (_chain_file_it), NULL));
 	}
 	gee_collection_add ((GeeCollection*) l, file);
 	/* mark file as currently being visited */
@@ -414,15 +414,15 @@ static void vala_code_context_visit (ValaCodeContext* self, ValaSourceFile* file
 	{
 		GeeList* _tmp0;
 		GeeIterator* _tmp1;
-		GeeIterator* dep_it;
+		GeeIterator* _dep_it;
 		_tmp0 = NULL;
 		_tmp1 = NULL;
-		dep_it = (_tmp1 = gee_iterable_iterator ((GeeIterable*) (_tmp0 = vala_source_file_get_header_internal_dependencies (file))), (_tmp0 == NULL) ? NULL : (_tmp0 = (gee_collection_object_unref (_tmp0), NULL)), _tmp1);
-		while (gee_iterator_next (dep_it)) {
+		_dep_it = (_tmp1 = gee_iterable_iterator ((GeeIterable*) (_tmp0 = vala_source_file_get_header_internal_dependencies (file))), (_tmp0 == NULL) ? NULL : (_tmp0 = (gee_collection_object_unref (_tmp0), NULL)), _tmp1);
+		while (gee_iterator_next (_dep_it)) {
 			ValaSourceFile* _tmp2;
 			ValaSourceFile* dep;
 			_tmp2 = NULL;
-			dep = (_tmp2 = (ValaSourceFile*) gee_iterator_get (dep_it), (_tmp2 == NULL) ? NULL : vala_source_file_ref (_tmp2));
+			dep = (_tmp2 = (ValaSourceFile*) gee_iterator_get (_dep_it), (_tmp2 == NULL) ? NULL : vala_source_file_ref (_tmp2));
 			if (file == dep) {
 				(dep == NULL) ? NULL : (dep = (vala_source_file_unref (dep), NULL));
 				continue;
@@ -435,13 +435,13 @@ static void vala_code_context_visit (ValaCodeContext* self, ValaSourceFile* file
 				gee_collection_add ((GeeCollection*) self->priv->cycles, cycle);
 				cycle_start_found = FALSE;
 				{
-					GeeIterator* cycle_file_it;
-					cycle_file_it = gee_iterable_iterator ((GeeIterable*) l);
-					while (gee_iterator_next (cycle_file_it)) {
+					GeeIterator* _cycle_file_it;
+					_cycle_file_it = gee_iterable_iterator ((GeeIterable*) l);
+					while (gee_iterator_next (_cycle_file_it)) {
 						ValaSourceFile* cycle_file;
 						ValaSourceFileCycle* _tmp3;
 						ValaSourceFileCycle* ref_cycle_file_cycle;
-						cycle_file = (ValaSourceFile*) gee_iterator_get (cycle_file_it);
+						cycle_file = (ValaSourceFile*) gee_iterator_get (_cycle_file_it);
 						_tmp3 = NULL;
 						ref_cycle_file_cycle = (_tmp3 = vala_source_file_get_cycle (cycle_file), (_tmp3 == NULL) ? NULL : vala_source_file_cycle_ref (_tmp3));
 						if (!cycle_start_found) {
@@ -465,13 +465,13 @@ static void vala_code_context_visit (ValaCodeContext* self, ValaSourceFile* file
 							/* file is in an other cycle, merge the two cycles */
 							gee_collection_remove ((GeeCollection*) self->priv->cycles, vala_source_file_get_cycle (cycle_file));
 							{
-								GeeIterator* inner_cycle_file_it;
-								inner_cycle_file_it = gee_iterable_iterator ((GeeIterable*) vala_source_file_get_cycle (cycle_file)->files);
-								while (gee_iterator_next (inner_cycle_file_it)) {
+								GeeIterator* _inner_cycle_file_it;
+								_inner_cycle_file_it = gee_iterable_iterator ((GeeIterable*) vala_source_file_get_cycle (cycle_file)->files);
+								while (gee_iterator_next (_inner_cycle_file_it)) {
 									ValaSourceFile* _tmp4;
 									ValaSourceFile* inner_cycle_file;
 									_tmp4 = NULL;
-									inner_cycle_file = (_tmp4 = (ValaSourceFile*) gee_iterator_get (inner_cycle_file_it), (_tmp4 == NULL) ? NULL : vala_source_file_ref (_tmp4));
+									inner_cycle_file = (_tmp4 = (ValaSourceFile*) gee_iterator_get (_inner_cycle_file_it), (_tmp4 == NULL) ? NULL : vala_source_file_ref (_tmp4));
 									if (vala_source_file_get_cycle (inner_cycle_file) != cycle) {
 										/* file in inner cycle not yet added to outer cycle */
 										gee_collection_add ((GeeCollection*) cycle->files, inner_cycle_file);
@@ -479,7 +479,7 @@ static void vala_code_context_visit (ValaCodeContext* self, ValaSourceFile* file
 									}
 									(inner_cycle_file == NULL) ? NULL : (inner_cycle_file = (vala_source_file_unref (inner_cycle_file), NULL));
 								}
-								(inner_cycle_file_it == NULL) ? NULL : (inner_cycle_file_it = (gee_collection_object_unref (inner_cycle_file_it), NULL));
+								(_inner_cycle_file_it == NULL) ? NULL : (_inner_cycle_file_it = (gee_collection_object_unref (_inner_cycle_file_it), NULL));
 							}
 						} else {
 							gee_collection_add ((GeeCollection*) cycle->files, cycle_file);
@@ -488,7 +488,7 @@ static void vala_code_context_visit (ValaCodeContext* self, ValaSourceFile* file
 						(cycle_file == NULL) ? NULL : (cycle_file = (vala_source_file_unref (cycle_file), NULL));
 						(ref_cycle_file_cycle == NULL) ? NULL : (ref_cycle_file_cycle = (vala_source_file_cycle_unref (ref_cycle_file_cycle), NULL));
 					}
-					(cycle_file_it == NULL) ? NULL : (cycle_file_it = (gee_collection_object_unref (cycle_file_it), NULL));
+					(_cycle_file_it == NULL) ? NULL : (_cycle_file_it = (gee_collection_object_unref (_cycle_file_it), NULL));
 				}
 				(cycle == NULL) ? NULL : (cycle = (vala_source_file_cycle_unref (cycle), NULL));
 			} else {
@@ -499,7 +499,7 @@ static void vala_code_context_visit (ValaCodeContext* self, ValaSourceFile* file
 			}
 			(dep == NULL) ? NULL : (dep = (vala_source_file_unref (dep), NULL));
 		}
-		(dep_it == NULL) ? NULL : (dep_it = (gee_collection_object_unref (dep_it), NULL));
+		(_dep_it == NULL) ? NULL : (_dep_it = (gee_collection_object_unref (_dep_it), NULL));
 	}
 	/* mark file as successfully visited */
 	vala_source_file_set_mark (file, 2);
