@@ -30,10 +30,12 @@
 #include <string.h>
 #include <vala/valareferencetype.h>
 #include <vala/valaerrordomain.h>
+#include <vala/valaerrorcode.h>
 #include <vala/valasourcereference.h>
 #include <vala/valadatatype.h>
 #include <vala/valascope.h>
 #include <vala/valasymbol.h>
+#include <vala/valasemanticanalyzer.h>
 
 G_BEGIN_DECLS
 
@@ -62,10 +64,12 @@ struct _ValaErrorTypeClass {
 };
 
 
-ValaErrorType* vala_error_type_construct (GType object_type, ValaErrorDomain* error_domain, ValaSourceReference* source_reference);
-ValaErrorType* vala_error_type_new (ValaErrorDomain* error_domain, ValaSourceReference* source_reference);
+ValaErrorType* vala_error_type_construct (GType object_type, ValaErrorDomain* error_domain, ValaErrorCode* error_code, ValaSourceReference* source_reference);
+ValaErrorType* vala_error_type_new (ValaErrorDomain* error_domain, ValaErrorCode* error_code, ValaSourceReference* source_reference);
 ValaErrorDomain* vala_error_type_get_error_domain (ValaErrorType* self);
 void vala_error_type_set_error_domain (ValaErrorType* self, ValaErrorDomain* value);
+ValaErrorCode* vala_error_type_get_error_code (ValaErrorType* self);
+void vala_error_type_set_error_code (ValaErrorType* self, ValaErrorCode* value);
 GType vala_error_type_get_type (void);
 
 
