@@ -55,15 +55,15 @@ ValaInstanceCast* vala_instance_cast_construct (GType object_type, ValaCCodeExpr
 	char* _tmp0;
 	g_return_val_if_fail (expr != NULL, NULL);
 	g_return_val_if_fail (type != NULL, NULL);
-	self = ((ValaInstanceCast*) (g_type_create_instance (object_type)));
+	self = (ValaInstanceCast*) g_type_create_instance (object_type);
 	vala_instance_cast_set_inner (self, expr);
 	vala_instance_cast_set_type_reference (self, type);
 	_tmp1 = NULL;
 	_tmp0 = NULL;
-	vala_ccode_function_call_set_call (((ValaCCodeFunctionCall*) (self)), ((ValaCCodeExpression*) ((_tmp1 = vala_ccode_identifier_new ((_tmp0 = vala_typesymbol_get_upper_case_cname (self->priv->_type_reference, NULL)))))));
-	(_tmp1 == NULL ? NULL : (_tmp1 = (vala_ccode_node_unref (_tmp1), NULL)));
+	vala_ccode_function_call_set_call ((ValaCCodeFunctionCall*) self, (ValaCCodeExpression*) (_tmp1 = vala_ccode_identifier_new (_tmp0 = vala_typesymbol_get_upper_case_cname (self->priv->_type_reference, NULL))));
+	(_tmp1 == NULL) ? NULL : (_tmp1 = (vala_ccode_node_unref (_tmp1), NULL));
 	_tmp0 = (g_free (_tmp0), NULL);
-	vala_ccode_function_call_add_argument (((ValaCCodeFunctionCall*) (self)), VALA_CCODE_EXPRESSION (self->priv->_inner));
+	vala_ccode_function_call_add_argument ((ValaCCodeFunctionCall*) self, VALA_CCODE_EXPRESSION (self->priv->_inner));
 	return self;
 }
 
@@ -97,7 +97,7 @@ void vala_instance_cast_set_inner (ValaInstanceCast* self, ValaCCodeExpression*
 	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_inner = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_ccode_node_ref (_tmp1))), (self->priv->_inner == NULL ? NULL : (self->priv->_inner = (vala_ccode_node_unref (self->priv->_inner), NULL))), _tmp2);
+	self->priv->_inner = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : vala_ccode_node_ref (_tmp1)), (self->priv->_inner == NULL) ? NULL : (self->priv->_inner = (vala_ccode_node_unref (self->priv->_inner), NULL)), _tmp2);
 }
 
 
@@ -116,7 +116,7 @@ static void vala_instance_cast_instance_init (ValaInstanceCast * self) {
 static void vala_instance_cast_finalize (ValaCCodeNode* obj) {
 	ValaInstanceCast * self;
 	self = VALA_INSTANCE_CAST (obj);
-	(self->priv->_inner == NULL ? NULL : (self->priv->_inner = (vala_ccode_node_unref (self->priv->_inner), NULL)));
+	(self->priv->_inner == NULL) ? NULL : (self->priv->_inner = (vala_ccode_node_unref (self->priv->_inner), NULL));
 	VALA_CCODE_NODE_CLASS (vala_instance_cast_parent_class)->finalize (obj);
 }
 
